#include <actuators.h>
#include <buzzer.h>
#include <hitachi.h>
#include <inputs.h>
#include <outputs.h>
#include <pwm.h>
#include <uart.h>
#include <timers.h>
#include <avr/interrupt.h>

int main(void) {
	// Initialiseer alle libraries
	inputsInit();
	outputsInit();
	pwmInit();
	pwmConfigure(PWM_SPEED_244, PWM_STATE_NORMAL, PWM_STATE_INVERTED);
	displayInit(20, 2);				// Initialize 20 x 2 display
	displayBacklight(1);
	uartInit(UART_BAUD_9600, 1);
	timersInit();
	actuatorsInit(25, 103, 0, 0);
	actuatorsEnable(1, 1);		
	buzzerInit();
	sei();							// Enable interrupts
	
	// Schrijf "Hello world!" op de eerste regel op het display
	displayGotoXY(0, 0);
	fputs("Hello world!", display);
	
	// Oneindige loop
	while (1) {
		if (inputsGet(1)) {			// Is knop 1 ingedrukt?
			outputsSet(1, 1);
			outputsSet(2, 0);
			displayGotoXY(0, 1);
			fputs("Knopje 1 ingedrukt!", display);
			fputs("Knopje 1 ingedrukt!\r\n", uart);
			pwmValueSet(1, 128);
			pwmValueSet(2, 128);
			actuatorsPositionSet(1, 25);
			
			// Maak een lage piep voor 250ms
			buzzerToneSet(200);
			buzzerEnable(1);
			timersWaitMs(250);
			buzzerEnable(0);
			
			while (inputsGet(1));	// Wacht tot knop is losgelaten			
		} else if (inputsGet(2)) {	// Is knop 2 ingedrukt?
			outputsSet(1, 0);
			outputsSet(2, 1);
			displayGotoXY(0, 1);
			fputs("Knopje 2 ingedrukt!", display);
			fputs("Knopje 2 ingedrukt!\r\n", uart);
			pwmValueSet(1, 256);
			pwmValueSet(2, 256);
			actuatorsPositionSet(1, 75);
			
			// Maak een hoge piep voor 250ms
			buzzerToneSet(400);
			buzzerEnable(1);
			timersWaitMs(250);
			buzzerEnable(0);
			
			while (inputsGet(2));	// Wacht tot knop is losgelaten
		} else {					// Geen knoppen ingedrukt
			outputsSet(1, 0);
			outputsSet(2, 0);
			displayGotoXY(0, 1);
			fputs("Geen knop ingedrukt", display);
			fputs("Geen knop ingedrukt\r\n", uart);
			
			while (!inputsGet(1) && !inputsGet(2));	// Wacht tot er een knop is ingedrukt
		}
	}
}